"Tape.foreground:			white",
"*XmDrawingArea.foreground:		white",
"*background:				#6e91aa",
"*highlightColor:			#cc686f",
"*XmDialogShell*background:		#8b979f",
"*Menubar*background:			#8b979f",
"*XmMenuShell*background:		#6e91aa",
"*XmList.background:			#e1ebe1",
"*XmText.background:			#e1ebe1",
"*XmTextField.background:		#e1ebe1",
"*XmDialogShell*XmList.background:	#e1ebe1",
"*XmDialogShell*XmText.background:	#e1ebe1",
"*XmDialogShell*XmTextField.background:	#e1ebe1",
"*Container.gridType:			grid_cell_shadow",
